@@ -132,7 +132,7 @@ if (!empty($piwik)) {
 </div>
 <!-- AJOUT -->
  <link rel="import" href="http://www.maine-et-loire.fr/fileadmin/dep49-header-footer/elements/elements.html">
-<script src="http://www.maine-et-loire.fr/fileadmin/dep49-header-footer/js/polyfillLoader.js"></script>  
+ <script src="http://www.maine-et-loire.fr/fileadmin/dep49-header-footer/js/polyfillLoader.js"></script>   
 
 <style>
 #headerContrast {
@@ -157,6 +157,12 @@ ul.subLevel1.active.style-scope.dep49-header {
 }
 
 
+#header-dep.headroom .dep-navigation ul.nav > li > a:hover{
+    color: #444444;
+
+}
+
+
 
 	</style>
 
